import numpy as np
def z(l,k,sort=True,reverse=True):
    '''
    Implementation of arXiv:1905.13729
    For l,k two set of same dimensions (or k with an extra dimension)
    return a builded array z, such that
     sum( z )=0
     sum( z**3)=0
    '''
    l=list(l)
    k=list(k)
    #Build vector-like solutions x,y
    if len(l)==len(k) :
        x=np.array( [l[0]]+k+[-l[0]]+[-i for i in k ])
        y=np.array( [0,0] +l        +[-i for i in l ])
    else:
        x=np.array( [0]+k+[-i for i in k ] )
        y=np.array( l+[k[0]]+[0]+[-i for i in l ]+[-k[0]])
    xfac=0
    yfac=0
    # Build not trivial solution
    zz=(x*y**2).sum()*x-(x**2*y).sum()*y
    if sort:
        zz=sorted( zz ,key=abs, reverse=reverse ) 
    return np.array(zz)

free=z



#!/usr/bin/env python3
# coding: utf-8

# Copyright (c) Colav.
# Distributed under the terms of the Modified BSD License.

# -----------------------------------------------------------------------------
# Minimal Python version sanity check (from IPython)
# -----------------------------------------------------------------------------

# See https://stackoverflow.com/a/26737258/2268280
# sudo pip3 install twine
# python3 setup.py sdist bdist_wheel
# twine upload dist/*
# For test purposes
# twine upload --repository-url https://test.pypi.org/legacy/ dist/*

from __future__ import print_function
from setuptools import setup, find_packages

import os
import sys


v = sys.version_info

shell = False
if os.name in ('nt', 'dos'):
    shell = True
    warning = "WARNING: Windows is not officially supported"
    print(warning, file=sys.stderr)


def main():
    setup(
        # Application name:
        name="anomalies",

        # Version number (initial):
        version="0.0.2-alpha",

        # Application author details:
        author="restrepo",
        author_email="restrepo@udea.edu.co",

        # Packages
        packages=find_packages(exclude=['tests']),

        # Include additional files into the package
        include_package_data=True,

        # Details
        url="https://github.com/restrepo/anomaly",

        #
        license="BSD",

        description="Anomaly cancellation",

        long_description=open("README.md").read(),

        long_description_content_type="text/markdown",

        # Dependent packages (distributions)
        install_requires=[
            'numpy'
        ],
    )


if __name__ == "__main__":
    main()
